/*
###########################################################################
#                                                                         #
# File   :	main.h                                                    #
# Project:	PP - Prometheus Project                                   #
#                                                                         #
# Started:	02.04.98                                                  #
# Changed:	02.04.98                                                  #
# Author :      Gerhard Vogt                                              #
#                                                                         #
# Copyright (C) 1998 by Gerhard Vogt                                      #
#                                                                         #
# This program is free software; you can redistribute it and/or modify    #
# it under the terms of the GNU General Public License as published by    #
# the Free Software Foundation; either version 2 of the License, or       #
# (at your option) any later version.                                     #
#                                                                         #
# This program is distributed in the hope that it will be useful,         #
# but WITHOUT ANY WARRANTY; without even the implied warranty of          #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
# GNU General Public License for more details.                            #
#                                                                         #
# You should have received a copy of the GNU General Public License       #
# along with this program; if not, write to the Free Software             #
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.               #
# See the file "COPYING" in the base directory of this distribution       #
# for more.                                                               #
#                                                                         #
###########################################################################
*/
#include "pic2.h"
#include "leiste.h"
#include "minikarte.h"
#include "sbarv.h"
#include "sbarh.h"
#include <qlabel.h>
#include <qpushbt.h>
#include <qlayout.h>
#include <qscrbar.h>
#include <qdialog.h>
#include <qlayout.h>
#include <qapp.h>
#include <qpopmenu.h>
#include <qmenubar.h>
#include <qpaintd.h>
#include <qmovie.h>
#include <qframe.h>
#include <qtabdlg.h>
#include <qslider.h>
#include <qradiobt.h>
#include <qbttngrp.h>
#include <qfiledlg.h>
#include <qfile.h>
#include <qdstream.h>
#include <qmsgbox.h>
#include <qlistbox.h>
#include <qcombo.h>
#include <qkeycode.h>

#ifndef MAIN_H
#define MAIN_H

class Modal : public QDialog 
{
  Q_OBJECT

  public:
    Modal( QWidget *parent=0, const char *name=0 );
    QPushButton *ok, *cancel;
};

class Grad : public QDialog 
{
  Q_OBJECT

  public:
    Grad( QWidget *parent=0, const char *name=0 );
    QPushButton *ok;
    QListBox *lb;
      QLabel *info;
     QString text2;
int num;

public slots:
   void changeGradSlotInt (int grad);

signals:
   void gradChangedSignal (int num);
};

class briefingInfo : public QWidget
{
  Q_OBJECT

  public:
    briefingInfo( QWidget *parent=0, const char *name=0, int num=1,
                 const char *text=0);
    int yText;
    QLabel *briefingLabel;

  public slots:
    void moveLabelSlot (int y);
};

class Tasten : public QDialog 
{
  Q_OBJECT

  public:
    Tasten( QWidget *parent=0, const char *name=0 );
    QPushButton *ok, *cancel;
};

class About : public QDialog 
{
  Q_OBJECT

  public:
    About( QWidget *parent=0, const char *name=0,
           QString picPfad="" );
    void paintEvent(QPaintEvent* event);
    QPushButton *ok;
    QPixmap bg;
    QPainter p;
    QRect r1;

};

class Level : public QDialog 
{
  Q_OBJECT

  public:
    Level( QWidget *parent=0, const char *name=0, int num=1,
           QString picPfad2="" );
    void resizeEvent (QResizeEvent *);
    void paintEvent(QPaintEvent* event);
    QLabel *movielabel;
    QMovie movie;
    QPixmap bg;
    QPushButton *ok, *cancel;
    int gNum;
    QString picPfad;
    briefingInfo *info;
    QPainter p;
    QRect r1;
    QScrollBar *briefingBar;
};



class MainWidget : public QWidget
{
  Q_OBJECT
 
  public:
    MainWidget( QWidget *parent=0, const char *name=0,
                QString localPfad="" );
    void resizeEvent (QResizeEvent *);
//    void mouseMoveEvent(QMouseEvent *event);
    void mousePressEvent (QMouseEvent *);
    void paintEvent(QPaintEvent* event);
    void keyPressEvent(QKeyEvent *);
    void openLevel(const char *fName);
    void loadGame (QString fName);

    typedef struct 
    {
        int EnergieGesamt1, EnergieGesamt2, killsCars, losesCars;
        int killsBuildings, losesBuildings, sieg;
    } winDatenType;

    int pauseStatus, pauseID, version, noMovie;
    winDatenType winDaten;
    QPushButton *quit, *unselectButton;
    QRect r1;
    QRadioButton *rb, *rb2;
    QSlider *slider, *slider2, *slider3, *slider4, *slider5;
    PicLoad *test;
    leiste *Leiste;
    miniKarte *Karte;
    sBarV *scrollKarteY;
    sBarH *scrollKarteX;
    Modal *m;
    About *ab;
    QLabel *movielabel;
    QMessageBox *msg;
    QMovie movie;
    QMenuBar *menu;
    QPopupMenu *file;
    QPopupMenu *level;
    QPopupMenu *help;
    Level *level1Dialog;
    Modal *Dia;
    QString levelPath, picPfad;
    Grad *grad;
    QPainter p;
    QLabel *energieLabel, *descriptionLabel;
    typedef struct
    {
      int karte[karteRangeY+1][karteRangeX+1];
    } kartetyp;
    kartetyp mKarte;
    QScrollBar *sBar;
    QScrollBar *sButtonBarV;
    int title;
    QPixmap pm;

  public slots:
   void saveSlot(QString fName);
   void noMovieSlot (int status);
   void open ();
   void level1();
   void level2();
   void level3();
   void level4();
   void level5();
   void level6();
   void level7();
   void helpSlot();
   void level8();
   void level9();
   void level10();
   void level2_alt ();
   void pause ();
   void pref ();
   void siegSlot (int gruppe, winDatenType winDaten);
   void okSlot();
   void save();
   void aboutSlot ();
   void tastenSlot ();
   void mapInfoHelpSlot();
   void userLevel();

};
#endif
